#ifndef OPENREADCLOSE_H
#define OPENREADCLOSE_H

#include "stralloc.h"

int openreadclose(const char *filename,stralloc *buf,size_t initiallength);

#endif
